=======
History
=======

0.3.0 (2020-03-27)
------------------

* Revised RSR_reader.
* RSR_reader now accepts a logger and may ignore missing files.
* Added list of supported sensors to README.rst.
* Fixed pipeline badge.


0.1.0 (2019-08-19)
------------------

* First release on PyPI.
